"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDistributionTable = void 0;
const date_fns_1 = require("date-fns");
const getCompletionStreams_1 = require("../velocity/getCompletionStreams");
const getStreamsDistribution_1 = require("../velocity/getStreamsDistribution");
const createDistributionTable = (teams, userConfig) => {
    let distributionTable = '';
    let reportDate = '';
    for (const team of teams) {
        let completionStreams = (0, getCompletionStreams_1.getCompletionStreams)(team, 6);
        completionStreams = (0, getStreamsDistribution_1.getStreamsDistribution)(completionStreams);
        if (distributionTable === '') {
            distributionTable = `| Team | Velocity (Pts) | Velocity (Tkts) | ${completionStreams
                .map(s => s.name)
                .join(' | ')} | \n`;
            distributionTable += `| --- | --- | --- | ${completionStreams
                .map(() => '---')
                .join(' | ')} | \n`;
        }
        const lastWeek = completionStreams[0].weeks.slice(-2)[1];
        // const lastWeek = completionStreams[0].weeks[completionStreams[0].weeks - 1]
        distributionTable += `| ${team.name} | ${Math.round(lastWeek.metrics.points.totalStreams)} /wk | ${Math.round(lastWeek.metrics.issues.totalStreams)} /wk | ${completionStreams
            .map(cs => {
            const lastWeek = cs.weeks.slice(-3)[2];
            const lastWeekDistribution = lastWeek.metrics.points.distribution;
            const earlierWeek = cs.weeks.slice(-3)[0];
            const earlierWeekDistribution = earlierWeek.metrics.points.distribution;
            let variance = '';
            if (lastWeekDistribution > earlierWeekDistribution + 5) {
                variance = `↗️ _(${Math.round(earlierWeekDistribution)}%)_`;
            }
            else if (lastWeekDistribution < earlierWeekDistribution - 5) {
                variance = `↘️ _(${Math.round(earlierWeekDistribution)}%)_`;
            }
            return `[${Math.round(lastWeekDistribution)}%](${encodeURI(`${userConfig.jira.host}/issues/?jql=key in (${lastWeek.velocity.issues
                .map((i) => i.key)
                .join()})`)}) ${variance}`;
        })
            .join(' | ')} | \n`;
        const earlierWeek = completionStreams[0].weeks.slice(-3)[0];
        reportDate = (0, date_fns_1.format)(earlierWeek.firstDay, 'LLLL dd, yyyy');
    }
    distributionTable += `\n`;
    distributionTable += `<sub>ℹ️ Displays team metrics as well as the distribution of its completion in various areas. Velocity is expressed per week.</sub> \n`;
    distributionTable += `<sub>ℹ️ ↗️ or ↘️ Indicates variation greater than 5% when compared to the week of ${reportDate}. Value from the week of ${reportDate} in between "()"</sub> \n`;
    return distributionTable;
};
exports.createDistributionTable = createDistributionTable;
