"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createReleasePipelineTable = void 0;
const date_fns_1 = require("date-fns");
const jiraUtils_1 = require("../misc/jiraUtils");
const createReleasePipelineTable = (releaseTickets, userConfig) => {
    let releaseTable = '';
    releaseTable += `| Release | Status | Sprint | Released date | Progress (Tkts) | \n`;
    releaseTable += `| --- | --- | --- | --- | --- | \n`;
    for (let releaseTicket of releaseTickets) {
        releaseTicket = (0, jiraUtils_1.cleanIssue)(releaseTicket, userConfig.jira.fields.sprint);
        const sprint = releaseTicket.fields.sprint !== undefined &&
            releaseTicket.fields.sprint !== null
            ? releaseTicket.fields.sprint.map((s) => s.name).join(', ')
            : '';
        const fixVersions = releaseTicket.fields.fixVersions === undefined
            ? []
            : releaseTicket.fields.fixVersions.map((i) => i.name);
        let resolutionDate = '';
        if (releaseTicket.fields.resolutiondate !== undefined &&
            releaseTicket.fields.resolutiondate !== null) {
            resolutionDate = (0, date_fns_1.format)(new Date(releaseTicket.fields.resolutiondate), 'LLL dd, yyyy');
        }
        const allIssues = releaseTicket.issuesInRelease;
        const completedIssues = releaseTicket.issuesInRelease.filter((i) => i.status.statusCategory.name === 'Done');
        let progessTktsPrct = 0;
        if (completedIssues.length > 0) {
            progessTktsPrct = Math.round((completedIssues.length * 100) / allIssues.length);
        }
        const progessTkts = `${progessTktsPrct}% ([${completedIssues.length}](${encodeURI(
        // `${userConfig.jira.host}/issues/?jql=key in (${completedIssues
        //   .map((i: any) => i.key)
        //   .join()})`,
        `${userConfig.jira.host}/issues/?jql=fixVersion = ${fixVersions[0]} and statusCategory = Done`)})/[${allIssues.length}](${encodeURI(
        // `${userConfig.jira.host}/issues/?jql=key in (${allIssues
        //   .map((i: any) => i.key)
        //   .join()})`,
        `${userConfig.jira.host}/issues/?jql=fixVersion = ${fixVersions[0]}`)}))`;
        for (const fixVersion of fixVersions) {
            releaseTable += `| [${fixVersion}](${userConfig.jira.host}/browse/${releaseTicket.key}) | ${releaseTicket.fields.status.name} | ${sprint} | ${resolutionDate} | ${progessTkts} | \n`;
        }
    }
    releaseTable += `\n`;
    releaseTable += `<sub>ℹ️ Displays releases in the current sprint or planned in future sprints as well as releases completed in the past 30 days.</sub> \n`;
    return releaseTable;
};
exports.createReleasePipelineTable = createReleasePipelineTable;
