"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCompletionStreams = void 0;
const date_fns_1 = require("date-fns");
const getEmptyCalendar_1 = require("./getEmptyCalendar");
// From completion data, format the streams with the actual velocity
const getCompletionStreams = (completionData, completionWindowMonths) => {
    console.log('[Teams] Calculating Teams completion streams');
    const velocityWeeks = 4;
    const emptyCalendar = (0, getEmptyCalendar_1.getEmptyCalendar)(new Date(completionData.from), new Date());
    return completionData.completion.map((s) => {
        const issues = s.issues.map(i => {
            const days = s.days.map(d => {
                return {
                    day: d.day,
                    issues: d.issues.filter(di => i.issues.includes(di.key)),
                };
            });
            const emptyCalendarSub = (0, getEmptyCalendar_1.getEmptyCalendar)((0, date_fns_1.sub)(new Date(), { months: completionWindowMonths }), new Date());
            return Object.assign(Object.assign({}, i), { weeks: emptyCalendarSub.map((w) => {
                    const completedDays = days.filter((d) => (0, date_fns_1.isEqual)((0, date_fns_1.startOfWeek)(new Date(d.day)), w.firstDay));
                    const completedIssues = completedDays.reduce((acc, day) => {
                        return [...acc, ...day.issues];
                    }, []);
                    // Gather data for velocity window
                    const velocityDays = s.days.filter((d) => new Date(d.day) < w.firstDay &&
                        (0, date_fns_1.differenceInWeeks)(w.firstDay, (0, date_fns_1.startOfWeek)(new Date(d.day))) <=
                            velocityWeeks);
                    const velocityIssues = velocityDays.reduce((acc, day) => {
                        return [...acc, ...day.issues];
                    }, []);
                    return Object.assign(Object.assign({}, w), { issues: completedIssues, completed: {
                            days: completedDays,
                            issues: completedIssues,
                        }, velocity: {
                            days: velocityDays,
                            issues: velocityIssues,
                        }, metrics: {
                            issues: {
                                count: completedIssues.length,
                                velocity: velocityIssues.length / velocityWeeks,
                            },
                            points: {
                                count: completedIssues
                                    .map((j) => j.points)
                                    .reduce((acc, value) => acc + value, 0),
                                velocity: velocityIssues
                                    .map((j) => j.points)
                                    .reduce((acc, value) => acc + value, 0) /
                                    velocityWeeks,
                            },
                        } });
                }) });
        });
        return Object.assign(Object.assign({}, s), { issues, days: s.days.map(d => {
                return Object.assign(Object.assign({}, d), { day: new Date(d.day) });
            }), weeks: emptyCalendar.map((w) => {
                // Filter by days completed during that week
                const completedDays = s.days.filter((d) => (0, date_fns_1.isEqual)((0, date_fns_1.startOfWeek)(new Date(d.day)), w.firstDay));
                const completedIssues = completedDays.reduce((acc, day) => {
                    return [...acc, ...day.issues];
                }, []);
                // Gather data for velocity window
                const velocityDays = s.days.filter((d) => new Date(d.day) < w.firstDay &&
                    (0, date_fns_1.differenceInWeeks)(w.firstDay, (0, date_fns_1.startOfWeek)(new Date(d.day))) <=
                        velocityWeeks);
                const velocityIssues = velocityDays.reduce((acc, day) => {
                    return [...acc, ...day.issues];
                }, []);
                return Object.assign(Object.assign({}, w), { completed: {
                        days: completedDays,
                        issues: completedIssues,
                    }, velocity: {
                        days: velocityDays,
                        issues: velocityIssues,
                    }, metrics: {
                        issues: {
                            count: completedIssues.length,
                            velocity: velocityIssues.length / velocityWeeks,
                        },
                        points: {
                            count: completedIssues
                                .map((j) => j.points)
                                .reduce((acc, value) => acc + value, 0),
                            velocity: velocityIssues
                                .map((j) => j.points)
                                .reduce((acc, value) => acc + value, 0) /
                                velocityWeeks,
                        },
                    } });
            }) });
    });
};
exports.getCompletionStreams = getCompletionStreams;
